@@ -8,14 +8,14 @@ from glob import glob
 modname = "conference"
 distname = "cubicweb-%s" % modname
 
-numversion = (0, 16, 1)
+numversion = (0, 17, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
 description = "conference component for the CubicWeb framework"
 author = "Logilab"
 author_email = "contact@logilab.fr"
-web = "https://www.cubicweb.org/project/%s" % distname
+web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname
 
 classifiers = [
     "Environment :: Web Environment",
@@ -25,7 +25,7 @@ classifiers = [
 ]
 
 __depends__ = {
-    "cubicweb": ">= 3.29",
+    "cubicweb": ">= 3.29, < 3.36.0",
     "cubicweb-addressbook": None,
     "cubicweb-card": ">=1.1.0",
     "cubicweb-comment": None,
